# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 20010 Akretion LDTA (<http://www.akretion.com>).
#    @author Raphaël Valyi
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.     
#
##############################################################################

import time
import ir
from tools.translate import _

from osv import osv, fields

class project_importer(osv.osv_memory):
    _name = "project.importer"
    _description = 'Import projects'

    _columns = {
        'project_template_ids': fields.many2many('project.project', 'project_template_rel', 'parent_id', 'child_id', 'Project Templates', domain="[['state', '=', 'template']]"),
    }

    def do_import(self, cr, uid, ids, context):
        rec_ids = context and context.get('active_ids',[])
        project_obj = self.pool.get('project.project')
        phase_obj = self.pool.get('project.phase')
        res_alloc_obj = self.pool.get('project.resource.allocation')
        projects = project_obj.browse(cr, uid, rec_ids, context)

        undef_res_id = self.pool.get('ir.model.data').search(cr, uid, [['name', '=', 'undef_resource']])[0]['res_id'] #TODO make it work if project_resource_extended not installed!
        for importer in self.browse(cr, uid, ids):    
            for project in projects:
                for project_template in importer.project_template_ids:
                    ids_map = {}
                    phases = []
                    for phase in project_template.phase_ids:
                        new_phase_id = phase_obj.copy(cr, uid, phase.id, {'project_id': project.id, 'progress': 0, 'picking_ids': [(6, 0, [])], 'name': "(%s) " % project_template.name  + phase.name}, context)
                        ids_map[phase.id] = int(new_phase_id)
                        phase = phase_obj.browse(cr, uid, new_phase_id, context)
                        phases += [phase]
                        for resource_allocation in phase.resource_ids:
                            res_alloc_obj.write(cr, uid, [resource_allocation.id], {'product_id': resource_allocation.product_id.id, 'resource_id': undef_res_id, 'sale_id': False})
                    for phase in phases: #re-attach predecessors and successors copies:
                        successors = []
                        predecessors = []
                        for succ in phase.next_phase_ids:
                            if not ids_map.get(succ.id, False):
                                successors += [succ.id]
                        for pred in phase.previous_phase_ids:
                            if not ids_map.get(pred.id, False):
                                predecessors += [pred.id]
    
                        phase_obj.write(cr, uid, [phase.id], {'next_phase_ids': [(6, 0, successors)], 'previous_phase_ids': [(6, 0, predecessors)]})
        return {}

project_importer()

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

